% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/getIdsMrna.R
\name{getIdsMrna}
\alias{getIdsMrna}
\title{getIdsMrna}
\usage{
getIdsMrna(MAE, mRNA, mirror, species, orgDB)
}
\arguments{
\item{MAE}{MultiAssayExperiment to store the output of getIdsMrna.
It is recommended to use the MAE which contains output from startObject.}

\item{mRNA}{Dataframe. Rownames are genes and columns are results of DE.
This should be found as an assay within the MAE used in the startObject
function. Please read vignette for nomenclature guidance.}

\item{mirror}{String to identify which biomaRt server is best. This is based
on location. Either 'useast', 'uswest', 'asia' or 'www'. Default is 'www'.}

\item{species}{Species of interest. E.g. mmusculus or hsapiens.}

\item{orgDB}{org.xx.eg.db package which corresponds to the species being
analysed.}
}
\value{
2 new dataframes in the MAE. One with entrez information and
the other with ensembl gene ID information.
}
\description{
getIdsMrna will produce ensembl and entrez ID dataframes
for mRNAs. These will be stored as 2 individual assays within a MAE.

This function will attempt to use biomaRt in the first instance. If server
issues occur, it will instead use clusterProfiler. Generally biomaRt has
more annotation IDs, but the results between these methods will vary.
}
\examples{
library(org.Mm.eg.db)
data(mm_mRNA)

mRNA <- mm_mRNA[1:20,]

MAE <- startObject(miR = NULL, mRNA = mRNA)

MAE <- getIdsMrna(MAE = MAE, mRNA = assay(MAE, 2), mirror = 'useast',
                      species = 'mmusculus', orgDB = org.Mm.eg.db)
}
